# simple plotting + fitting

Doc: <https://apn-pucky.github.io/smpl/index.html>

| [Stable][doc stable]        | [Test][doc test]           |
| ------------- |:-------------:|
| [![PyPI version][pypi image]][pypi link]      | - |
| [![workflow][a s image]][a s link]      | [![test][a t image]][a t link]     |
| ![downloads](https://img.shields.io/pypi/dm/smpl.svg) | -     |
| [![Codacy Badge][codacy quality image]][codacy quality link] | -     |
| [![Codacy Badge][codacy cover image]][codacy cover link] | -      |
| [![Coverage Status][c s i]][c s l] | [![Coverage Status][c t i]][c t l] |

## Versions

### stable

```sh
pip install smpl
```

Optional: --user or --upgrade

### test

```sh
pip install --index-url https://test.pypi.org/simple/ smpl
```

[doc stable]: https://apn-pucky.github.io/smpl/index.html
[doc test]: https://apn-pucky.github.io/smpl/test/index.html

[pypi image]: https://badge.fury.io/py/smpl.svg
[pypi link]: https://pypi.org/project/smpl/

[a s image]: https://github.com/APN-Pucky/smpl/actions/workflows/release.yml/badge.svg
[a s link]: https://github.com/APN-Pucky/smpl/actions/workflows/release.yml
[a t link]:https://github.com/APN-Pucky/smpl/actions/workflows/test.yml
[a t image]:https://github.com/APN-Pucky/smpl/actions/workflows/test.yml/badge.svg

[codacy quality image]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2
[codacy quality link]: https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade
[codacy cover image]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2
[codacy cover link]: https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage

[c s i]: https://coveralls.io/repos/github/APN-Pucky/smpl/badge.svg?branch=master
[c s l]: https://coveralls.io/github/APN-Pucky/smpl?branch=stable
[c t l]: https://coveralls.io/github/APN-Pucky/smpl?branch=test
[c t i]: https://coveralls.io/repos/github/APN-Pucky/smpl/badge.svg?branch=test
